var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Device } from "@capacitor/device";
/**
 * Asynchronously retrieves comprehensive information about the device.
 *
 * This function aggregates data from various sources, specifically using several methods from the `Device` class
 * provided by the "@capacitor/device" module. The methods used include:
 *  - Device.getInfo()
 *  - Device.getBatteryInfo()
 *  - Device.getId()
 *  - Device.getLanguageCode()
 *
 * The return object includes data from all of these sources.
 *
 * @returns {Promise<AllDeviceInfo>} A Promise that resolves with an `AllDeviceInfo` object that includes all device information.
 *
 * @example
 * ```
 * getAllDeviceInfo().then(info => console.log(info));
 * ```
 *
 * Note: To get detailed documentation about the methods used from the `Device` class, refer to the official
 * documentation for "@capacitor/device".
 *
 * @export
 * @async
 * @function getAllDeviceInfo
 */
export function getAllDeviceInfo() {
    return __awaiter(this, void 0, void 0, function* () {
        return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, (yield Device.getInfo())), (yield Device.getBatteryInfo())), (yield Device.getId())), {
            languageCode: (yield Device.getLanguageCode()).value,
        }), {
            languageTag: (yield Device.getLanguageCode()).value,
        });
    });
}
