var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { DEVICE_PACKAGE_NAME } from './package-name.js';
import { getAllDeviceInfo } from './get-all-device-info.js';
/**
 * Inserts a device into the Deep
 *
 * @param param The parameters required for the device insertion.
 * @returns A promise that resolves with the result of the device insertion.
 *
 * @remarks
 * If the {@link InsertDeviceParam.info} parameter is undefined, the function will call {@link getAllDeviceInfo} to get the device information.
 * If the {@link InsertDeviceParam.containerLinkId} parameter is undefined, the device link will be contained in the {@link InsertDeviceParam.deep.linkId}.
 *
 * @example
 * ```ts
const {deviceLink} = await insertDevice({
  deep,
  containerLinkId: deep.linkId,
  info: await getAllDeviceInfo(),
});
 */
export function insertDevice(param) {
    return __awaiter(this, void 0, void 0, function* () {
        const { deep, info = yield getAllDeviceInfo(), containerLinkId = deep.linkId, } = param;
        const deviceTypeLinkId = yield deep.id(DEVICE_PACKAGE_NAME, 'Device');
        const containTypeLinkId = yield deep.id('@deep-foundation/core', 'Contain');
        let { data: [deviceLink], } = yield deep.insert({
            type_id: deviceTypeLinkId,
            in: {
                data: [
                    {
                        type_id: containTypeLinkId,
                        from_id: containerLinkId,
                    },
                ],
            },
            object: {
                data: {
                    value: info,
                },
            },
        }, { returning: deep.selectReturning });
        return { deviceLink };
    });
}
