import { DeepClient } from '@deep-foundation/deeplinks/imports/client.js';
/**
 * A custom React Hook that checks if a device link exists in the Deep database, and if not, it inserts one. Also saves device information to deep on render.
 *
 * @remarks
 * If the passed {@link UseDeviceInsertionIfDoesNotExistAndSavingInfoParam.deviceLinkId} is not undefined, the hook verifies its existence in Deep. If it does not exist, a new device link is inserted.
 *
 * It is recommended to use {@link WithDeviceInsertionIfDoesNotExistAndSavingData} instead of using this hook directly
 *
 * @param param An object of type {@link UseDeviceInsertionIfDoesNotExistAndSavingInfoParam}.
 *
 * @returns An object of type {@link UseDeviceInsertionIfDoesNotExistAndSavingInfoResult}
 */
export declare function useDeviceInsertionIfDoesNotExistAndSavingData(param: UseDeviceInsertionIfDoesNotExistAndSavingInfoParam): UseDeviceInsertionIfDoesNotExistAndSavingInfoResult;
/**
 * Describes the parameter object that should be passed to the {@link useDeviceInsertionIfDoesNotExistAndSavingData} hook.
 */
export interface UseDeviceInsertionIfDoesNotExistAndSavingInfoParam {
    /**
     * A DeepClient instance.
     */
    deep: DeepClient;
    /**
     * A device link ID.
     *
     * This field is not of type undefined because you should not call this component until you get the device link ID which is known. For these reasons there is {@link WithDeviceInsertionIfDoesNotExistAndSavingData}
     */
    deviceLinkId: number | null;
    setDeviceLinkId: (id: number | null) => void;
    containerLinkId: number;
}
/**
 * Describes the return object of the {@link useDeviceInsertionIfDoesNotExistAndSavingData} hook.
 */
export interface UseDeviceInsertionIfDoesNotExistAndSavingInfoResult {
    /**
     * Indicates the loading state of the device link insertion operation.
     */
    isLoading: boolean;
}
