var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useEffect, useState } from 'react';
import { insertDevice } from '../insert-device.js';
import { getAllDeviceInfo } from '../get-all-device-info.js';
/**
 * A custom React Hook that checks if a device link exists in the Deep database, and if not, it inserts one. Also saves device information to deep on render.
 *
 * @remarks
 * If the passed {@link UseDeviceInsertionIfDoesNotExistAndSavingInfoParam.deviceLinkId} is not undefined, the hook verifies its existence in Deep. If it does not exist, a new device link is inserted.
 *
 * It is recommended to use {@link WithDeviceInsertionIfDoesNotExistAndSavingData} instead of using this hook directly
 *
 * @param param An object of type {@link UseDeviceInsertionIfDoesNotExistAndSavingInfoParam}.
 *
 * @returns An object of type {@link UseDeviceInsertionIfDoesNotExistAndSavingInfoResult}
 */
export function useDeviceInsertionIfDoesNotExistAndSavingData(param) {
    const { deep, deviceLinkId, setDeviceLinkId, containerLinkId } = param;
    const [isLoading, setIsLoading] = useState(false);
    useEffect(() => {
        const fetchAndInsertDeviceLink = () => __awaiter(this, void 0, void 0, function* () {
            let deviceLink;
            if (deviceLinkId) {
                const { data } = yield deep.select(deviceLinkId);
                deviceLink = data[0];
            }
            if (!deviceLinkId || !deviceLink) {
                setIsLoading(true);
                const insertionResult = yield insertDevice({
                    deep,
                    containerLinkId,
                    info: yield getAllDeviceInfo(),
                });
                setDeviceLinkId(insertionResult.deviceLink.id);
                setIsLoading(false);
            }
        });
        fetchAndInsertDeviceLink();
    }, [deviceLinkId]);
    return { isLoading };
}
