import { useDeviceInsertionIfDoesNotExistAndSavingData } from './use-device-insertion-if-does-not-exist-and-saving-data.js';
/**
 * A higher-order component that handles the logic of inserting a device link into Deep if it does not exist and saving device information.
 *
 * @remarks
 * This component utilizes the custom hook {@link useDeviceInsertionIfDoesNotExistAndSavingData} to manage the device link insertion operation and handles the rendering logic based on the loading and insertion state of Device link insertion.
 *
 * @param props An object of type {@link WithDeviceInsertionIfDoesNotExistAndSavingDataParam}.
 *
 * @returns A JSX.Element that is either the children of this component if Device link is available, or the result of {@link WithDeviceInsertionIfDoesNotExistAndSavingDataParam.renderIfLoading} if the insertion operation is loading, or the result of {@link WithDeviceInsertionIfDoesNotExistAndSavingDataParam.renderIfNotInserted} if the device link is not inserted.
 */
export function WithDeviceInsertionIfDoesNotExistAndSavingData(props) {
    const { containerLinkId, deep, deviceLinkId, setDeviceLinkId, children, renderIfLoading, renderIfNotInserted, } = props;
    const { isLoading } = useDeviceInsertionIfDoesNotExistAndSavingData({
        deep,
        containerLinkId,
        deviceLinkId,
        setDeviceLinkId,
    });
    if (isLoading) {
        return renderIfLoading();
    }
    if (deviceLinkId) {
        return children;
    }
    else {
        return renderIfNotInserted();
    }
}
